@@ -1,7 +1,7 @@
 import os
 
 from .builder import Builder
-from .constants import DOCKER_COMPOSE_BASE, DOCKERFILE_CONTEXT, DOCKERFILE_PROXY
+from .constants import DOCKER_COMPOSE_BASE, DOCKERFILE_CONTEXT
 from ..app_config import AppConfig
 
 class AppBuilder(Builder):
@@ -18,9 +18,5 @@ class AppBuilder(Builder):
     return os.path.join(self.dir_path, DOCKERFILE_CONTEXT)
 
   @property
-  def proxy_base(self):
-    return 'proxy_base'
-
-  @property
-  def proxy_docker_file_path(self):
-    return os.path.join(self.dir_path, DOCKERFILE_PROXY)
\ No newline at end of file
+  def stoobly_base(self):
+    return 'stoobly_base'
\ No newline at end of file
